==> Java-Swing-0.03.tar.gz: Java-Swing-0.03/java/PerlCellEditorListener.java <==
import javax.swing.event.CellEditorListener;
import org.perl.inline.java.*;

public class      PerlCellEditorListener
       extends    InlineJavaPerlCaller
       implements CellEditorListener
{
    String sender;
    String callbacks;

    public PerlCellEditorListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void editingStopped(javax.swing.event.ChangeEvent event)  {
        try {
            CallPerl(
                "Java::Swing::CellEditorListener",
                "_CellEditorListener",
                new Object[] {sender, callbacks, "editingStopped", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void editingCanceled(javax.swing.event.ChangeEvent event)  {
        try {
            CallPerl(
                "Java::Swing::CellEditorListener",
                "_CellEditorListener",
                new Object[] {sender, callbacks, "editingCanceled", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}

==> Java-Swing-0.13.tar.gz: Java-Swing-0.13/java/PerlCellEditorListener.java <==
import javax.swing.event.CellEditorListener;
import org.perl.inline.java.*;

public class      PerlCellEditorListener
       extends    InlineJavaPerlCaller
       implements CellEditorListener
{
    String sender;
    String callbacks;

    public PerlCellEditorListener() throws InlineJavaException { }

    public PerlCellEditorListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void setSender   (String sender)    { this.sender    = sender; }
    public void setCallbacks(String callbacks) { this.callbacks = callbacks; }

    public void editingStopped(javax.swing.event.ChangeEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "editingStopped", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void editingCanceled(javax.swing.event.ChangeEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "editingCanceled", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}
